package com.example.topadapter;

import static com.anythink.core.api.ATInitMediation.getStringFromMap;

import android.app.Activity;
import android.content.Context;
import android.text.TextUtils;
import android.util.Log;
import android.view.View;

import com.anythink.banner.unitgroup.api.CustomBannerAdapter;
import com.anythink.core.api.ATAdConst;
import com.anythink.core.api.ATBiddingListener;
import com.anythink.core.api.ATBiddingResult;
import com.anythink.core.api.MediationInitCallback;
import com.open.ad.polyunion.bean.CAdInfo;
import com.open.ad.polyunion.listener.AdViewListener;
import com.open.ad.polyunion.view.AdConfig;
import com.open.ad.polyunion.view.AdRequestConfig;
import com.open.ad.polyunion.view.AdView;

import java.util.Map;

public class AlexCloooudBannerAdapter extends CustomBannerAdapter {
    private final String TAG = getClass().getSimpleName();
    boolean isC2SBidding = false;
    String slotId;
 
    private AdView mBannerView;

    @Override
    public View getBannerView() {
        Log.e("CLOOOUD_POLY", "getBannerView: " +(mBannerView == null)  );
        return mBannerView;
    }

    @Override
    public void loadCustomNetworkAd(final Context context, Map<String, Object> serverExtra,
                                    Map<String, Object> localExtra) {
        if (!(context instanceof Activity)) {
            notifyATLoadFail("", "OpenAD: context must be activity");
            return;
        }
        if (!initAndVerifyRequestParams(context, serverExtra, localExtra)) {
            notifyATLoadFail("", "app_id or slot_id is empty!");
            return;
        }

        AlexCloooudInitManager.getInstance()
                .initSDK(context, serverExtra, new MediationInitCallback() {
                    @Override
                    public void onSuccess() {
                        Log.e("CLOOOUD_POLY", "onSuccess: " );
                        int[] screenSizeDP = Util.getScreenSizeInDP(context);
                        AdRequestConfig requestConfig = new AdRequestConfig.Builder()
                                .AdType(AdConfig.AD_TYPE_BANNER)
                                .slotId(slotId) //广告场景id
                                .widthDp(screenSizeDP[0])
                                .heightDp(0)//0为自适应
                                .bannerInterval(0)//轮播时间 默认0
                                .build();
                        mBannerView = new AdView((Activity) context, requestConfig);
                        mBannerView.setListener(new AdViewListener() {
                            @Override
                            public void onAdClick() {
                                if (mImpressionEventListener != null) {
                                    mImpressionEventListener.onBannerAdClicked();
                                }
                            }

                            @Override
                            public void onAdFailed(String msg) {
                                notifyATLoadFail("9999", msg);
                            }

                            @Override
                            public void onAdReady(int price) {
                                Log.e("CLOOOUD_POLY", "onAdReady: "+isC2SBidding );
                                if (isC2SBidding) {
                                    runOnNetworkRequestThread(new Runnable() {
                                        @Override
                                        public void run() {
                                            mBiddingListener.onC2SBiddingResultWithCache(
                                                    ATBiddingResult.success((double) price/100,
                                                            System.currentTimeMillis() + "",
                                                            null, ATAdConst.CURRENCY.RMB),
                                                    null);
                                        }
                                    });
                                } else {
                                    if (mLoadListener != null) {
                                        mLoadListener.onAdCacheLoaded();
                                    }
                                }
                            }

                            @Override
                            public void onAdShow(CAdInfo cAdInfo) {
                                Log.e("CLOOOUD_POLY", "onAdShow: " );
                                if (mImpressionEventListener != null) {
                                    mImpressionEventListener.onBannerAdShow();
                                }
                            }

                            @Override
                            public void onAdDismissed(String s) {

                            }
                        });

                    }

                    @Override
                    public void onFail(String errorMsg) {
                        notifyATLoadFail("", errorMsg);
                    }
                });
    }

    @Override
    public boolean startBiddingRequest(Context context, Map<String, Object> serverExtra,
                                       Map<String, Object> localExtra,
                                       ATBiddingListener biddingListener) {
        isC2SBidding = true;
        loadCustomNetworkAd(context, serverExtra, localExtra);
        return true;
    }

    private boolean initAndVerifyRequestParams(Context context, Map<String, Object> serverExtra,
                                               Map<String, Object> localExtra) {
        String appId = getStringFromMap(serverExtra, "app_id");
        slotId = getStringFromMap(serverExtra, "slot_id");

        if (TextUtils.isEmpty(appId) || TextUtils.isEmpty(slotId)) {
            return false;
        }

        return true;
    }


    @Override
    public void destory() {
        if (mBannerView != null) {
            mBannerView.onDestroyAd();
        }
    }


    @Override
    public String getNetworkPlacementId() {
        return slotId;
    }

    @Override
    public String getNetworkSDKVersion() {
        return "";
    }

    @Override
    public String getNetworkName() {
        return "OpenAD";
    }

    @Override
    public Map<String, Object> getNetworkInfoMap() {
        return null;
    }
}
