package com.example.topadapter;

import android.app.Application;
import android.content.Context;
import android.util.Log;

import com.anythink.core.api.ATInitMediation;
import com.anythink.core.api.ATSDK;
import com.anythink.core.api.MediationInitCallback;
import com.open.ad.cloooud.api.listener.COaidProvider;
import com.open.ad.polyunion.newedition.contract.DeniedUpDeviceInfo;
import com.open.ad.polyunion.newedition.contract.InitSDKListener;
import com.open.ad.polyunion.view.AdConfig;
import com.open.ad.polyunion.view.AdView;
import com.open.ad.polyunion.view.InitSDKConfig;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.concurrent.atomic.AtomicBoolean;

public class AlexCloooudInitManager extends ATInitMediation {

    private static final String TAG = AlexCloooudInitManager.class.getSimpleName();
    private volatile static AlexCloooudInitManager sInstance;
    private AtomicBoolean mIsIniting;
    private boolean mHasInit;
    private List<MediationInitCallback> mListeners;
    private final Object mLock = new Object();


    public static AlexCloooudInitManager getInstance() {
        if (sInstance == null) {
            synchronized (AlexCloooudInitManager.class) {
                if (sInstance == null) {
                    sInstance = new AlexCloooudInitManager();
                }
            }
        }
        return sInstance;
    }

    private AlexCloooudInitManager() {
        mIsIniting = new AtomicBoolean(false);
    }

    @Override
    public void initSDK(Context context, Map<String, Object> serviceExtras,
                        MediationInitCallback callback) {
        if(mHasInit){
            if (callback != null) {
                callback.onSuccess();
            }
            return;
        }

        synchronized (mLock) {
            if (mIsIniting.get()) {
                if (callback != null) {
                    mListeners.add(callback);
                }
                return;
            }

            if (mListeners == null) {
                mListeners = new ArrayList<>();
            }

            mIsIniting.set(true);
        }

        final String appId = getStringFromMap(serviceExtras, "app_id");

        if (callback != null) {
            mListeners.add(callback);
        }


        final Context applicationContext = context.getApplicationContext();
        final String appName = context.getPackageManager()
                .getApplicationLabel(context.getApplicationInfo()).toString();

        runOnMainThread(() -> {
            if (ATSDK.isNetworkLogDebug()) {
                Log.d(TAG,
                        "start init,OpenADAdapter");
            }
            try {
                //聚合SDK初始化
                InitSDKConfig initSDKConfig  = new InitSDKConfig.Builder()
                        .AppId(appId)
                        .appName(appName)//SDK后台注册的应用名称
//                    .setChannel("demo")//渠道
                        // 竖屏 - AdConfig.REWARD_VIDEO_SCREEN_VERTICAL
                        // 横屏 - AdConfig.REWARD_VIDEO_SCREEN_x`HORIZONTAL
                        .RewardVideoScreenDirection(AdConfig.REWARD_VIDEO_SCREEN_VERTICAL) // 设置激励视频播放页面的横竖屏
                        .debug(true)////上线需要设置false
                        .setDeniedUpDeviceInfo(new DeniedUpDeviceInfo() {
                        })
                        .setOaidProvider(new COaidProvider() {
                            @Override
                            public String getOaid() {
                                return "";
                            }
                        }) //传入 OAID 获取器，建议集成 OAID SDK的应用设置
                        .build();
                AdView.initSDK((Application) applicationContext, initSDKConfig, new InitSDKListener() {
                    @Override
                    public void initializeSucceed() {
                        //初始化成功
                        runOnThreadPool(new Runnable() {
                            @Override
                            public void run() {
                                mHasInit = true;
                                callbackResult(true, null, null);
                            }
                        });
                    }

                    @Override
                    public void initializeFail() {
                        //初始化失败
                        callbackResult(false,   "10000", "初始化失败");
                    }
                });
            } catch (Throwable e) {
                callbackResult(false, "", e.getMessage());
            }
        });
    }


    private void callbackResult(boolean success, String errorCode, String errorMsg) {
        synchronized (mLock) {
            int size = mListeners.size();
            MediationInitCallback initListener;
            for (int i = 0; i < size; i++) {
                initListener = mListeners.get(i);
                if (initListener != null) {
                    if (success) {
                        initListener.onSuccess();
                    } else {
                        initListener.onFail(errorCode + " | " + errorMsg);
                    }
                }
            }
            mListeners.clear();

            mIsIniting.set(false);
        }
    }

    @Override
    public String getNetworkName() {
        return "OpenAD";
    }

    @Override
    public String getNetworkVersion() {
        return "";
    }

    @Override
    public String getNetworkSDKClass() {
        return "com.open.ad.polyunion.view.AdView";
    }






}
