package com.example.topadapter;

import static com.anythink.core.api.ATInitMediation.getStringFromMap;

import android.app.Activity;
import android.content.Context;
import android.text.TextUtils;

import com.anythink.core.api.ATAdConst;
import com.anythink.core.api.ATBiddingListener;
import com.anythink.core.api.ATBiddingResult;
import com.anythink.core.api.MediationInitCallback;
import com.anythink.interstitial.unitgroup.api.CustomInterstitialAdapter;
import com.open.ad.polyunion.bean.CAdInfo;
import com.open.ad.polyunion.listener.AdViewListener;
import com.open.ad.polyunion.view.AdConfig;
import com.open.ad.polyunion.view.AdRequestConfig;
import com.open.ad.polyunion.view.AdView;

import java.util.Map;

public class AlexCloooudInterstitialAdapter extends CustomInterstitialAdapter {

    boolean isC2SBidding = false;
    String slotId;
    private AdView interstialAd;
    @Override
    public void loadCustomNetworkAd(final Context context, Map<String, Object> serverExtra,
                                    Map<String, Object> localExtra) {
        if (!(context instanceof Activity)) {
            notifyATLoadFail("", "OpenAD: context must be activity");
            return;
        }
        if (!initAndVerifyRequestParams(context, serverExtra, localExtra)) {
            notifyATLoadFail("", "app_id or slot_id is empty!");
            return;
        }

        AlexCloooudInitManager.getInstance()
                .initSDK(context, serverExtra, new MediationInitCallback() {
                    @Override
                    public void onSuccess() {
                        AdRequestConfig requestConfig = new AdRequestConfig.Builder()
                                .AdType(AdConfig.AD_TYPE_INTERSTITIAL)
                                .slotId(slotId) //广告场景id
                                .widthDp(300)
                                .heightDp(300)
                                .build();
                        interstialAd = new AdView((Activity) context, requestConfig);
                        interstialAd.setListener(new AdViewListener() {
                            @Override
                            public void onAdClick() {
                                if (mImpressListener != null) {
                                    mImpressListener.onInterstitialAdClicked();
                                }
                            }

                            @Override
                            public void onAdFailed(String msg) {
                                notifyATLoadFail("9999", msg);
                            }

                            @Override
                            public void onAdReady(int price) {
                                if (isC2SBidding) {
                                    runOnNetworkRequestThread(new Runnable() {
                                        @Override
                                        public void run() {
                                            mBiddingListener.onC2SBiddingResultWithCache(
                                                    ATBiddingResult.success((double) price/100,
                                                            System.currentTimeMillis() + "",
                                                            null, ATAdConst.CURRENCY.RMB),
                                                    null);
                                        }
                                    });
                                } else {
                                    if (mLoadListener != null) {
                                        mLoadListener.onAdCacheLoaded();
                                    }
                                }
                            }

                            @Override
                            public void onAdShow(CAdInfo cAdInfo) {
                                if (mImpressListener != null) {
                                    mImpressListener.onInterstitialAdShow();
                                }
                            }

                            @Override
                            public void onAdDismissed(String s) {
                                if (mImpressListener != null) {
                                    mImpressListener.onInterstitialAdClose();
                                }
                            }
                        });

                    }

                    @Override
                    public void onFail(String errorMsg) {
                        notifyATLoadFail("", errorMsg);
                    }
                });

    }

    @Override
    public boolean startBiddingRequest(Context context, Map<String, Object> serverExtra,
                                       Map<String, Object> localExtra,
                                       ATBiddingListener biddingListener) {
        isC2SBidding = true;
        loadCustomNetworkAd(context, serverExtra, localExtra);
        return true;
    }


    @Override
    public void show(Activity activity) {
        if (isAdReady()) {
            if (interstialAd != null) {
                interstialAd.showInterstialAd(activity);
            }
        }
    }

    private boolean initAndVerifyRequestParams(Context context, Map<String, Object> serverExtra,
                                               Map<String, Object> localExtra) {
        String appId = getStringFromMap(serverExtra, "app_id");
        slotId = getStringFromMap(serverExtra, "slot_id");

        if (TextUtils.isEmpty(appId) || TextUtils.isEmpty(slotId)) {
            return false;
        }

        return true;
    }

    @Override
    public void destory() {
        if (interstialAd != null) {
            interstialAd.onDestroyAd();
        }
    }


    @Override
    public String getNetworkPlacementId() {
        return slotId;
    }

    @Override
    public String getNetworkSDKVersion() {
        return "";
    }

    @Override
    public String getNetworkName() {
        return "OpenAD";
    }

    @Override
    public boolean isAdReady() {
        return true;
    }

    @Override
    public Map<String, Object> getNetworkInfoMap() {
        return null;
    }
}
