package com.example.topadapter;

import static com.anythink.core.api.ATInitMediation.getStringFromMap;

import android.app.Activity;
import android.content.Context;
import android.text.TextUtils;
import android.util.Log;

import com.anythink.core.api.ATAdConst;
import com.anythink.core.api.ATBiddingListener;
import com.anythink.core.api.ATBiddingResult;
import com.anythink.core.api.MediationInitCallback;
import com.anythink.nativead.unitgroup.api.CustomNativeAd;
import com.anythink.nativead.unitgroup.api.CustomNativeAdapter;
import com.open.ad.polyunion.listener.NativeAdsListener;
import com.open.ad.polyunion.view.AdConfig;
import com.open.ad.polyunion.view.AdRequestConfig;
import com.open.ad.polyunion.view.NativeAd;
import com.open.ad.polyunion.view.NativeAdsResponse;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

public class AlexCloooudNativeAdapter extends CustomNativeAdapter {

    boolean isC2SBidding = false;
    String slotId;

    @Override
    public void loadCustomNetworkAd(final Context context, Map<String, Object> serverExtra,
                                    Map<String, Object> localExtra) {
        if (!(context instanceof Activity)) {
            notifyATLoadFail("", "OpenAD: context must be activity");
            return;
        }
        if (!initAndVerifyRequestParams(context, serverExtra, localExtra)) {
            notifyATLoadFail("", "app_id or slot_id is empty!");
            return;
        }

        AlexCloooudInitManager.getInstance()
                .initSDK(context, serverExtra, new MediationInitCallback() {
                    @Override
                    public void onSuccess() {
                        int[] screenSizeDP = Util.getScreenSizeInDP(context);
                        AdRequestConfig requestConfig = new AdRequestConfig.Builder()
                                .AdType(AdConfig.AD_TYPE_INTERSTITIAL)
                                .slotId(slotId) //广告场景id
                                .isVideoVoiceOn(false)//视频播放是否有声音
                                .requestCount(1) //信息流广告请求条数
                                .widthDp(screenSizeDP[0]) //请求图片宽度dp值
                                .heightDp(0) //请求图片高度dp值
                                /**
                                 * 设置视频自动播放场景：
                                 * ALWAYS - 所有网络环境均自动播放
                                 * WIFI - WIFI网络环境自动播放
                                 * NEVER - 所有网络环境均不会自动播放
                                 */
                                .videoAutoPlayPolicy(AdRequestConfig.VideoAutoPlayPolicy.ALWAYS) //                .addSougouAdTemplate(AdTemplate.BIG_IMG_TPL_ID)
                                //                .addSougouAdTemplate(AdTemplate.DOWNLOAD_BIG_TPL_ID)
                                .showDownloadConfirmDialog(true)
                                .build();

                        NativeAd nativeAds = new NativeAd(context, requestConfig);
                        nativeAds.setListener(new NativeAdsListener() {
                            @Override
                            public void onAdReady(List<NativeAdsResponse> responses) {
                                if (responses == null || responses.size() == 0) {
                                    notifyATLoadFail("9999", "没有返回数据");
                                    return;
                                }
                                NativeAdsResponse response = responses.get(0);
                                loadSelfRenderFeedAd(context, responses);
                            }

                            @Override
                            public void onAdFailed(String msg) {
                                Log.e("CLOOOUDAD", "NativeAd onAdFailed: $s");
                                notifyATLoadFail("9999", msg);
                            }
                        });
                    }

                    @Override
                    public void onFail(String errorMsg) {
                        notifyATLoadFail("", errorMsg);
                    }
                });

    }


    private void loadSelfRenderFeedAd(Context context, List<? extends NativeAdsResponse> list) {
        List<CustomNativeAd> resultList = new ArrayList<>();
        for (NativeAdsResponse response : list) {
            AlexOpenADNativeAd ttNativeAd = new AlexOpenADNativeAd(context, response);
            resultList.add(ttNativeAd);
        }

        CustomNativeAd[] customNativeAds = new CustomNativeAd[resultList.size()];
        customNativeAds = resultList.toArray(customNativeAds);
        notifyLoadSuccess(list, customNativeAds);
    }

    private void notifyLoadSuccess(final List<? extends NativeAdsResponse> nativeAdList,
                                   final CustomNativeAd... nativeAds) {

        if (nativeAdList.size() == 0 || nativeAds.length == 0) {
            notifyATLoadFail("", "Ad list is empty.");
            return;
        }

        if (isC2SBidding) {
            NativeAdsResponse response = nativeAdList.get(0);
            runOnNetworkRequestThread(new Runnable() {
                @Override
                public void run() {
                    try {
                        if (mBiddingListener != null) {
                            double price = response.getPrice();
                            Log.e("CLOOOUD_POLY", "run: "+price );
                            mBiddingListener.onC2SBiddingResultWithCache(
                                    ATBiddingResult.success((double) price/100,
                                            System.currentTimeMillis() + "",
                                            null, ATAdConst.CURRENCY.RMB),
                                    nativeAds[0]);
                        }
                    } catch (Throwable e) {

                    }
                }
            });
        } else {
            if (mLoadListener != null) {
                mLoadListener.onAdCacheLoaded(nativeAds);
            }
        }
    }


    @Override
    public boolean startBiddingRequest(Context context, Map<String, Object> serverExtra,
                                       Map<String, Object> localExtra,
                                       ATBiddingListener biddingListener) {
        isC2SBidding = true;
        loadCustomNetworkAd(context, serverExtra, localExtra);
        return true;
    }

    private boolean initAndVerifyRequestParams(Context context, Map<String, Object> serverExtra,
                                               Map<String, Object> localExtra) {
        String appId = getStringFromMap(serverExtra, "app_id");
        slotId = getStringFromMap(serverExtra, "slot_id");

        if (TextUtils.isEmpty(appId) || TextUtils.isEmpty(slotId)) {
            return false;
        }
        return true;
    }


    @Override
    public void destory() {

    }

    @Override
    public String getNetworkPlacementId() {
        return slotId;
    }

    @Override
    public String getNetworkSDKVersion() {
        return "";
    }

    @Override
    public String getNetworkName() {
        return "OpenAD";
    }
}
